diff mbox

infiniband-diags/vendstat: Indicate general info for IS4 as well as IS3

Message ID 20100210143205.GA11779@comcast.net (mailing list archive)
State Not Applicable, archived
Headers show

Commit Message

Hal Rosenstock Feb. 10, 2010, 2:32 p.m. UTC
None
diff mbox

Patch

diff --git a/infiniband-diags/man/vendstat.8 b/infiniband-diags/man/vendstat.8
index 76d0cfb..2a87f2b 100644
--- a/infiniband-diags/man/vendstat.8
+++ b/infiniband-diags/man/vendstat.8
@@ -1,4 +1,4 @@ 
-.TH VENDSTAT 8 "April 16, 2009" "OpenIB" "OpenIB Diagnostics"
+.TH VENDSTAT 8 "February 10, 2010" "OpenIB" "OpenIB Diagnostics"
 
 .SH NAME
 vendstat \- query InfiniBand vendor specific functions
@@ -20,7 +20,7 @@  Mellanox InfiniSwitch-III (IS3) and InfiniSwitch-IV (IS4).
 .PP
 .TP
 \fB\-N\fR
-show IS3 general information.
+show IS3 or IS4 general information.
 .TP
 \fB\-w\fR
 show IS3 port xmit wait counters.
@@ -97,7 +97,7 @@  attempted to be fulfilled, and will fail if it is not possible.
 .SH EXAMPLES
 
 .PP
-vendstat -N 6		# read IS3 general information
+vendstat -N 6		# read IS3 or IS4 general information
 .PP
 vendstat -w 6		# read IS3 port xmit wait counters
 .PP
@@ -110,4 +110,4 @@  vendstat -c 2,8 6 12	# configure IS4 port 12 counter groups for PortRcvDataSL
 .SH AUTHOR
 .TP
 Hal Rosenstock
-.RI < halr@voltaire.com >
+.RI < hal.rosenstock@gmail.com >
diff --git a/infiniband-diags/src/vendstat.c b/infiniband-diags/src/vendstat.c
index aeb7b66..abff83a 100644
--- a/infiniband-diags/src/vendstat.c
+++ b/infiniband-diags/src/vendstat.c
@@ -240,7 +240,7 @@  int main(int argc, char **argv)
 	int i;
 
 	const struct ibdiag_opt opts[] = {
-		{"N", 'N', 0, NULL, "show IS3 general information"},
+		{"N", 'N', 0, NULL, "show IS3 or IS4 general information"},
 		{"w", 'w', 0, NULL, "show IS3 port xmit wait counters"},
 		{"i", 'i', 0, NULL, "show IS4 counter group info"},
 		{"c", 'c', 1, "<num,num>", "configure IS4 counter groups"},
@@ -249,7 +249,7 @@  int main(int argc, char **argv)
 
 	char usage_args[] = "<lid|guid> [port]";
 	const char *usage_examples[] = {
-		"-N 6\t\t# read IS3 general information",
+		"-N 6\t\t# read IS3 or IS4 general information",
 		"-w 6\t\t# read IS3 port xmit wait counters",
 		"-i 6 12\t# read IS4 port 12 counter group info",
 		"-c 0,1 6 12\t# configure IS4 port 12 counter groups for PortXmitDataSL",
@@ -317,7 +317,7 @@  int main(int argc, char **argv)
 	gi = (is3_general_info_t *) & buf;
 
 	if (general_info) {
 		/* dump IS3 general info here */
 		printf("hw_dev_rev:  0x%04x\n", ntohs(gi->hw_info.hw_revision));
 		printf("hw_dev_id:   0x%04x\n", ntohs(gi->hw_info.device_id));
 		printf("hw_uptime:   0x%08x\n", ntohl(gi->hw_info.uptime));
@@ -317,7 +317,7 @@  int main(int argc, char **argv)
 
 	if (general_info) {
-		/* dump IS3 general info here */
+		/* dump IS3 or IS4 general info here */
 		printf("hw_dev_rev:  0x%04x\n", ntohs(gi->hw_info.hw_revision));
 		printf("hw_dev_id:   0x%04x\n", ntohs(gi->hw_info.device_id));